@@ -2,10 +2,10 @@ package App::ProxyHunter;
 
 use strict;
 use Coro::Select;
+use Coro::PatchSet;
 use Coro::LWP;
 use Coro::Timer;
 use Coro::Util;
-use Coro::PatchSet;
 use Coro;
 use LWP::UserAgent;
 use LWP::Protocol::https;
@@ -25,7 +25,16 @@ use constant CORO_DELAY       => 5;
 use constant SELECT_LIMIT     => 100;
 use constant MAX_SEC_IN_QUEUE => 60;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
+
+*Net::Proxy::Type::_open_socket = sub {
+	# make Net::Proxy::Type Coro friendly
+	my ($self, $host, $port) = @_;
+	my $socket = Coro::Socket->new(PeerHost => $host, PeerPort => $port, Timeout => $self->{connect_timeout}) or return;
+	$socket->blocking(0);
+	
+	return $socket;
+};
 
 sub start {
 	my $class = shift;
@@ -138,7 +147,15 @@ sub _start_checkers {
 	
 	for (1..$config->checker->workers) {
 		push @coros, async {
-			my $type_checker = Net::Proxy::Type->new(http_strict => 1, noauth => 1);
+			my $type_checker = Net::Proxy::Type->new(
+				strict        => $config->checker->strict,
+				noauth        => 1,
+				url           => $config->checker->http_url,
+				keyword       => $config->checker->http_keyword,
+				https_url     => $config->checker->https_url,
+				https_keyword => $config->checker->https_keyword,
+			);
+			$type_checker->http_strict(1);
 			my $speed_checker = $config->checker->speed_check ?
 				LWP::UserAgent->new(agent => 'Mozilla 5.0', timeout => 10, parse_head => 0) :
 				undef;
@@ -159,7 +176,7 @@ sub _start_checkers {
 				}
 				
 				my $proxy = shift @queue;
-				my ($type, $conn_time) = $class->_check($type_checker, $proxy)
+				my ($type, $conn_time) = $class->_check($type_checker, $config->checker->types, $proxy)
 					or do {
 						$proxy->delete();
 						next;
@@ -200,7 +217,15 @@ sub _start_recheckers {
 	
 	for (1..$config->rechecker->workers) {
 		push @coros, async {
-			my $type_checker = Net::Proxy::Type->new(http_strict => 1, noauth => 1);
+			my $type_checker = Net::Proxy::Type->new(
+				strict        => $config->rechecker->strict,
+				noauth        => 1,
+				url           => $config->checker->http_url,
+				keyword       => $config->checker->http_keyword,
+				https_url     => $config->checker->https_url,
+				https_keyword => $config->checker->https_keyword,
+			);
+			$type_checker->http_strict(1);
 			my $speed_checker = $config->rechecker->speed_check ?
 				LWP::UserAgent->new(agent => 'Mozilla 5.0', timeout => 10, parse_head => 0) :
 				undef;
@@ -232,7 +257,7 @@ sub _start_recheckers {
 				
 				my $proxy = shift @queue;
 				my $fail;
-				if (my ($type, $conn_time) = $class->_check($type_checker, $proxy)) {
+				if (my ($type, $conn_time) = $class->_check($type_checker, $config->checker->types, $proxy)) {
 					$proxy->set('type', $type);
 					$proxy->set('conn_time', $conn_time);
 					
@@ -416,11 +441,12 @@ sub _get_queue {
 	return @rows;
 }
 
+my %name2type = reverse %Net::Proxy::Type::NAME;
 sub _check {
-	my ($class, $checker, $proxy) = @_;
+	my ($class, $checker, $types, $proxy) = @_;
 	
 	my $full_mask = 0;
-	$full_mask |= $_ for grep { $_ != UNKNOWN_PROXY && $_ != DEAD_PROXY } keys %Net::Proxy::Type::NAME;
+	$full_mask |= $_ for map { $name2type{$_} } @$types;
 	my @check_mask;
 	
 	if ($proxy->type) {
@@ -433,6 +459,7 @@ sub _check {
 	}
 	
 	for my $mask (@check_mask) {
+		next unless $mask;
 		my ($type, $conn_time) = $checker->get($proxy->host, $proxy->port, $mask);
 		
 		unless ($type == DEAD_PROXY || $type == UNKNOWN_PROXY) {
